@@ -9,15 +9,10 @@
 #include <string>
 #include <vector>
 
-struct MarkPoolConfig {
-	int from, to;
-};
-
 struct StreamConfig {
 	std::string url;  // As seen by the client.
 	std::string src;  // Can be empty.
 	size_t backlog_size;
-	int mark_pool;  // -1 for none.
 	uint32_t pacing_rate;  // In bytes per second. Default is ~0U (no limit).
 	enum { STREAM_ENCODING_RAW = 0, STREAM_ENCODING_METACUBE } encoding;
 };
@@ -25,8 +20,9 @@ struct StreamConfig {
 struct UDPStreamConfig {
 	sockaddr_in6 dst;
 	std::string src;  // Can be empty.
-	int mark_pool;  // -1 for none.
 	uint32_t pacing_rate;  // In bytes per second. Default is ~0U (no limit).
+	int ttl;  // Default is -1 (use operating system default).
+	int multicast_iface_index;  // Default is -1 (use operating system default).
 };
 
 struct AcceptorConfig {
@@ -41,7 +37,6 @@ struct LogConfig {
 struct Config {
 	bool daemonize;
 	int num_servers;
-	std::vector<MarkPoolConfig> mark_pools;
 	std::vector<StreamConfig> streams;
 	std::vector<UDPStreamConfig> udpstreams;
 	std::vector<AcceptorConfig> acceptors;
