@@ -22,7 +22,6 @@
 #include "input.h"
 #include "input_stats.h"
 #include "log.h"
-#include "markpool.h"
 #include "sa_compare.h"
 #include "serverpool.h"
 #include "state.pb.h"
@@ -35,7 +34,6 @@ using namespace std;
 
 AccessLogThread *access_log = NULL;
 ServerPool *servers = NULL;
-vector<MarkPool *> mark_pools;
 volatile bool hupped = false;
 volatile bool stopped = false;
 
@@ -151,11 +149,6 @@ void create_streams(const Config &config,
                     const set<string> &deserialized_urls,
                     multimap<string, InputWithRefcount> *inputs)
 {
-	for (unsigned i = 0; i < config.mark_pools.size(); ++i) {
-		const MarkPoolConfig &mp_config = config.mark_pools[i];
-		mark_pools.push_back(new MarkPool(mp_config.from, mp_config.to));
-	}
-
 	// HTTP streams.
 	set<string> expecting_urls = deserialized_urls;
 	for (unsigned i = 0; i < config.streams.size(); ++i) {
@@ -182,10 +175,6 @@ void create_streams(const Config &config,
 			                      Stream::Encoding(stream_config.encoding));
 		}
 
-		if (stream_config.mark_pool != -1) {
-			servers->set_mark_pool(stream_index, mark_pools[stream_config.mark_pool]);
-		}
-
 		servers->set_pacing_rate(stream_index, stream_config.pacing_rate);
 
 		string src = stream_config.src;
@@ -212,11 +201,11 @@ void create_streams(const Config &config,
 	// UDP streams.
 	for (unsigned i = 0; i < config.udpstreams.size(); ++i) {
 		const UDPStreamConfig &udpstream_config = config.udpstreams[i];
-		MarkPool *mark_pool = NULL;
-		if (udpstream_config.mark_pool != -1) {
-			mark_pool = mark_pools[udpstream_config.mark_pool];
-		}
-		int stream_index = servers->add_udpstream(udpstream_config.dst, mark_pool, udpstream_config.pacing_rate);
+		int stream_index = servers->add_udpstream(
+			udpstream_config.dst,
+			udpstream_config.pacing_rate,
+			udpstream_config.ttl,
+			udpstream_config.multicast_iface_index);
 
 		string src = udpstream_config.src;
 		if (!src.empty()) {
@@ -338,7 +327,7 @@ int main(int argc, char **argv)
 	char argv0_canon[PATH_MAX];
 	char config_filename_canon[PATH_MAX];
 
-	if (realpath(argv[0], argv0_canon) == NULL) {
+	if (realpath("/proc/self/exe", argv0_canon) == NULL) {
 		log_perror(argv[0]);
 		exit(1);
 	}
@@ -393,7 +382,7 @@ start:
 	if (state_fd != -1) {
 		log(INFO, "Deserializing state from previous process...");
 		string serialized;
-		if (!read_tempfile(state_fd, &serialized)) {
+		if (!read_tempfile_and_close(state_fd, &serialized)) {
 			exit(1);
 		}
 		if (!loaded_state.ParseFromString(serialized)) {
@@ -439,7 +428,7 @@ start:
 
 		// Deserialize the acceptors.
 		for (int i = 0; i < loaded_state.acceptors_size(); ++i) {
-			sockaddr_in6 sin6 = ExtractAddressFromAcceptorProto(loaded_state.acceptors(i));
+			sockaddr_in6 sin6 = extract_address_from_acceptor_proto(loaded_state.acceptors(i));
 			deserialized_acceptors.insert(make_pair(
 				sin6,
 				new Acceptor(loaded_state.acceptors(i))));
@@ -456,8 +445,7 @@ start:
 	vector<Acceptor *> acceptors = create_acceptors(config, &deserialized_acceptors);
 	
 	// Put back the existing clients. It doesn't matter which server we
-	// allocate them to, so just do round-robin. However, we need to add
-	// them after the mark pools have been set up.
+	// allocate them to, so just do round-robin.
 	for (int i = 0; i < loaded_state.clients_size(); ++i) {
 		if (deleted_urls.count(loaded_state.clients(i).url()) != 0) {
 			safe_close(loaded_state.clients(i).sock());
@@ -554,11 +542,6 @@ start:
 	}
 	delete servers;
 
-	for (unsigned i = 0; i < mark_pools.size(); ++i) {
-		delete mark_pools[i];
-	}
-	mark_pools.clear();
-
 	access_log->stop();
 	delete access_log;
 	shut_down_logging();
