@@ -19,7 +19,6 @@
 
 #include "accesslog.h"
 #include "log.h"
-#include "markpool.h"
 #include "metacube2.h"
 #include "mutexlock.h"
 #include "parse.h"
@@ -254,14 +253,6 @@ void Server::set_header(int stream_index, const string &http_header, const strin
 	streams[stream_index]->stream_header = stream_header;
 }
 	
-void Server::set_mark_pool(int stream_index, MarkPool *mark_pool)
-{
-	MutexLock lock(&mutex);
-	assert(clients.empty());
-	assert(stream_index >= 0 && stream_index < ssize_t(streams.size()));
-	streams[stream_index]->mark_pool = mark_pool;
-}
-
 void Server::set_pacing_rate(int stream_index, uint32_t pacing_rate)
 {
 	MutexLock lock(&mutex);
@@ -478,12 +469,6 @@ void Server::skip_lost_data(Client *client)
 		client->stream_pos = stream->bytes_received - stream->backlog_size;
 		client->bytes_lost += bytes_lost;
 		++client->num_loss_events;
-
-		double loss_fraction = double(client->bytes_lost) / double(client->bytes_lost + client->bytes_sent);
-		log(WARNING, "[%s] Client lost %lld bytes (total loss: %.2f%%), maybe too slow connection",
-			client->remote_addr.c_str(),
-			(long long int)(bytes_lost),
-			100.0 * loss_fraction);
 	}
 }
 
@@ -522,16 +507,6 @@ int Server::parse_request(Client *client)
 
 	client->url = request_tokens[1];
 	client->stream = stream;
-	if (client->stream->mark_pool != NULL) {
-		client->fwmark = client->stream->mark_pool->get_mark();
-	} else {
-		client->fwmark = 0;  // No mark.
-	}
-	if (setsockopt(client->sock, SOL_SOCKET, SO_MARK, &client->fwmark, sizeof(client->fwmark)) == -1) {                          
-		if (client->fwmark != 0) {
-			log_perror("setsockopt(SO_MARK)");
-		}
-	}
 	if (setsockopt(client->sock, SOL_SOCKET, SO_MAX_PACING_RATE, &client->stream->pacing_rate, sizeof(client->stream->pacing_rate)) == -1) {
 		if (client->stream->pacing_rate != ~0U) {
 			log_perror("setsockopt(SO_MAX_PACING_RATE)");
@@ -618,10 +593,6 @@ void Server::close_client(Client *client)
 	if (client->stream != NULL) {
 		delete_from(&client->stream->sleeping_clients, client);
 		delete_from(&client->stream->to_process, client);
-		if (client->stream->mark_pool != NULL) {
-			int fwmark = client->fwmark;
-			client->stream->mark_pool->release_mark(fwmark);
-		}
 	}
 
 	// Log to access_log.
