@@ -23,7 +23,6 @@ struct Stream;
 #define MAX_CLIENT_REQUEST 16384
 
 class CubemapStateProto;
-class MarkPool;
 class StreamProto;
 
 class Server : public Thread {
@@ -39,10 +38,6 @@ public:
 	                const std::string &http_header,
 	                const std::string &stream_header);
 
-	// Set that the given stream should use the given mark pool from now on.
-	// NOTE: This should be set before any clients are connected!
-	void set_mark_pool(int stream_index, MarkPool *mark_pool);
-
 	// Set that the given stream should use the given max pacing rate from now on.
 	// NOTE: This should be set before any clients are connected!
 	void set_pacing_rate(int stream_index, uint32_t pacing_rate);
