@@ -121,9 +121,9 @@ int ServerPool::add_stream_from_serialized(const StreamProto &stream, const vect
 	return num_http_streams++;
 }
 	
-int ServerPool::add_udpstream(const sockaddr_in6 &dst, MarkPool *mark_pool, int pacing_rate)
+int ServerPool::add_udpstream(const sockaddr_in6 &dst, int pacing_rate, int ttl, int multicast_iface_index)
 {
-	udp_streams.push_back(new UDPStream(dst, mark_pool, pacing_rate));
+	udp_streams.push_back(new UDPStream(dst, pacing_rate, ttl, multicast_iface_index));
 	return num_http_streams + udp_streams.size() - 1;
 }
 
@@ -187,13 +187,6 @@ vector<ClientStats> ServerPool::get_client_stats() const
 	return ret;
 }
 	
-void ServerPool::set_mark_pool(int stream_index, MarkPool *mark_pool)
-{
-	for (int i = 0; i < num_servers; ++i) {
-		servers[i].set_mark_pool(stream_index, mark_pool);
-	}
-}
-
 void ServerPool::set_pacing_rate(int stream_index, uint32_t pacing_rate)
 {
 	for (int i = 0; i < num_servers; ++i) {
