@@ -57,7 +57,7 @@ void StatsThread::do_work()
 			fprintf(fp, "%s %d %d %s %d %llu %llu %llu\n",
 			        client_stats[i].remote_addr.c_str(),
 			        client_stats[i].sock,
-			        client_stats[i].fwmark,
+			        0,  // Used to be fwmark.
 				client_stats[i].url.c_str(),
 				int(now - client_stats[i].connect_time),
 				(long long unsigned)(client_stats[i].bytes_sent),
